package com.oop_pub.design_patterns2.factories;

import com.oop_pub.design_patterns2.entities.Monster;
import com.oop_pub.design_patterns2.entities.Treasure;

import java.util.Random;

/**
 * Builds random monster objects. Hides the monster creation mechanism using
 * a factory method.
 */
public class MonsterFactory {
    private static MonsterFactory factory = null;

    private Treasure.DamageType[] types = Treasure.DamageType.values();
    private Random rand = new Random();

    public Treasure.DamageType randomDamageType() {
        return types[rand.nextInt(types.length)];
    }

    public static MonsterFactory getInstance() {

        if (factory == null)
            factory = new MonsterFactory();
        return factory;
    }

    private MonsterFactory() {
    }

    public Monster createMonster() {

        String[] names = {"Krark", "Okur", "Krerag", "Nukorg", "Ikag", "Krougrok",
                "Xaarut", "Yuwegruk", "Niukug", "Exikor"};

        return new Monster(names[rand.nextInt(names.length)], randomDamageType());
    }
}
/*
move Alice right
Hero Alice has found a monster: Xaarut
Xaarutis vulnerable agains: Blunt
H  1  1  1  M
0  0  M  1  0
0  0  0  M  0
0  0  T  T  0
0  0  T  T  0

>
attack Alice
Hero attacks with 10 damage
Aliceis attacking Xaarut
Hero hp left: 64
Monster hp left: 90
>
attack Alice
Hero attacks with 10 damage
Aliceis attacking Xaarut
Hero hp left: 22
Monster hp left: 80
>
attack Alice
Hero attacks with 10 damage
Aliceis attacking Xaarut
Hero hp left: -20
Monster hp left: 70
Hero Alice died !
H  1  1  1  M
0  0  M  1  0
0  0  0  M  0
0  0  T  T  0
0  0  T  T  0


 */